@@ -10,10 +10,9 @@ from .proto.cosmos.authz.v1beta1 import tx_pb2 as cosmos_authz_tx_pb
 from .proto.injective.exchange.v1beta1 import authz_pb2 as injective_authz_pb
 
 from .proto.cosmos.bank.v1beta1 import tx_pb2 as cosmos_bank_tx_pb
-from .proto.cosmos.base.v1beta1 import coin_pb2 as cosmos_base_coin_pb
 
 from .proto.injective.exchange.v1beta1 import tx_pb2 as injective_exchange_tx_pb
-from .proto.injective.exchange.v1beta1 import exchange_pb2 as injective_exchange_pb
+from pyinjective.proto.injective.exchange.v1beta1 import exchange_pb2 as injective_dot_exchange_dot_v1beta1_dot_exchange__pb2
 from .proto.injective.types.v1beta1 import tx_response_pb2 as tx_response_pb
 
 from .proto.injective.auction.v1beta1 import tx_pb2 as injective_auction_tx_pb
@@ -28,6 +27,8 @@ from .proto.cosmos.distribution.v1beta1 import tx_pb2 as cosmos_distribution_tx_
 
 from .proto.cosmos.gov.v1beta1 import tx_pb2 as cosmos_gov_tx_pb
 
+from pyinjective.proto.cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2
+
 from .constant import Denom
 from .utils import *
 from typing import List
@@ -40,27 +41,27 @@ class Composer:
         self.network = network
 
     def Coin(self, amount: int, denom: str):
-        return cosmos_base_coin_pb.Coin(amount=str(amount), denom=denom)
+        return cosmos_dot_base_dot_v1beta1_dot_coin__pb2.Coin(amount=str(amount), denom=denom)
 
     def get_order_mask(self, **kwargs):
         order_mask = 0
 
         if kwargs.get("is_conditional"):
-            order_mask += injective_exchange_pb.OrderMask.CONDITIONAL
+            order_mask += injective_dot_exchange_dot_v1beta1_dot_exchange__pb2.OrderMask.CONDITIONAL
         else:
-            order_mask += injective_exchange_pb.OrderMask.REGULAR
+            order_mask += injective_dot_exchange_dot_v1beta1_dot_exchange__pb2.OrderMask.REGULAR
 
         if kwargs.get("order_direction") == "buy":
-            order_mask += injective_exchange_pb.OrderMask.DIRECTION_BUY_OR_HIGHER
+            order_mask += injective_dot_exchange_dot_v1beta1_dot_exchange__pb2.OrderMask.DIRECTION_BUY_OR_HIGHER
 
         elif kwargs.get("order_direction") == "sell":
-            order_mask += injective_exchange_pb.OrderMask.DIRECTION_SELL_OR_LOWER
+            order_mask += injective_dot_exchange_dot_v1beta1_dot_exchange__pb2.OrderMask.DIRECTION_SELL_OR_LOWER
 
         if kwargs.get("order_type") == "market":
-            order_mask += injective_exchange_pb.OrderMask.TYPE_MARKET
+            order_mask += injective_dot_exchange_dot_v1beta1_dot_exchange__pb2.OrderMask.TYPE_MARKET
 
         elif kwargs.get("order_type") == "limit":
-            order_mask += injective_exchange_pb.OrderMask.TYPE_LIMIT
+            order_mask += injective_dot_exchange_dot_v1beta1_dot_exchange__pb2.OrderMask.TYPE_LIMIT
 
         if order_mask == 0:
             order_mask = 1
@@ -97,20 +98,20 @@ class Composer:
         trigger_price = spot_price_to_backend(0, denom)
 
         if kwargs.get("is_buy") and not kwargs.get("is_po"):
-            order_type = injective_exchange_pb.OrderType.BUY
+            order_type = injective_dot_exchange_dot_v1beta1_dot_exchange__pb2.OrderType.BUY
 
         elif not kwargs.get("is_buy") and not kwargs.get("is_po"):
-            order_type = injective_exchange_pb.OrderType.SELL
+            order_type = injective_dot_exchange_dot_v1beta1_dot_exchange__pb2.OrderType.SELL
 
         elif kwargs.get("is_buy") and kwargs.get("is_po"):
-            order_type = injective_exchange_pb.OrderType.BUY_PO
+            order_type = injective_dot_exchange_dot_v1beta1_dot_exchange__pb2.OrderType.BUY_PO
 
         elif not kwargs.get("is_buy") and kwargs.get("is_po"):
-            order_type = injective_exchange_pb.OrderType.SELL_PO
+            order_type = injective_dot_exchange_dot_v1beta1_dot_exchange__pb2.OrderType.SELL_PO
 
-        return injective_exchange_pb.SpotOrder(
+        return injective_dot_exchange_dot_v1beta1_dot_exchange__pb2.SpotOrder(
             market_id=market_id,
-            order_info=injective_exchange_pb.OrderInfo(
+            order_info=injective_dot_exchange_dot_v1beta1_dot_exchange__pb2.OrderInfo(
                 subaccount_id=subaccount_id,
                 fee_recipient=fee_recipient,
                 price=str(price),
@@ -151,32 +152,32 @@ class Composer:
         quantity = derivative_quantity_to_backend(quantity, denom)
 
         if kwargs.get("is_buy") and not kwargs.get("is_po"):
-            order_type = injective_exchange_pb.OrderType.BUY
+            order_type = injective_dot_exchange_dot_v1beta1_dot_exchange__pb2.OrderType.BUY
 
         elif not kwargs.get("is_buy") and not kwargs.get("is_po"):
-            order_type = injective_exchange_pb.OrderType.SELL
+            order_type = injective_dot_exchange_dot_v1beta1_dot_exchange__pb2.OrderType.SELL
 
         elif kwargs.get("is_buy") and kwargs.get("is_po"):
-            order_type = injective_exchange_pb.OrderType.BUY_PO
+            order_type = injective_dot_exchange_dot_v1beta1_dot_exchange__pb2.OrderType.BUY_PO
 
         elif not kwargs.get("is_buy") and kwargs.get("is_po"):
-            order_type = injective_exchange_pb.OrderType.SELL_PO
+            order_type = injective_dot_exchange_dot_v1beta1_dot_exchange__pb2.OrderType.SELL_PO
 
         elif kwargs.get("stop_buy"):
-            order_type = injective_exchange_pb.OrderType.STOP_BUY
+            order_type = injective_dot_exchange_dot_v1beta1_dot_exchange__pb2.OrderType.STOP_BUY
 
         elif kwargs.get("stop_sell"):
-            order_type = injective_exchange_pb.OrderType.STOP_SEll
+            order_type = injective_dot_exchange_dot_v1beta1_dot_exchange__pb2.OrderType.STOP_SEll
 
         elif kwargs.get("take_buy"):
-            order_type = injective_exchange_pb.OrderType.TAKE_BUY
+            order_type = injective_dot_exchange_dot_v1beta1_dot_exchange__pb2.OrderType.TAKE_BUY
 
         elif kwargs.get("take_sell"):
-            order_type = injective_exchange_pb.OrderType.TAKE_SELL
+            order_type = injective_dot_exchange_dot_v1beta1_dot_exchange__pb2.OrderType.TAKE_SELL
 
-        return injective_exchange_pb.DerivativeOrder(
+        return injective_dot_exchange_dot_v1beta1_dot_exchange__pb2.DerivativeOrder(
             market_id=market_id,
-            order_info=injective_exchange_pb.OrderInfo(
+            order_info=injective_dot_exchange_dot_v1beta1_dot_exchange__pb2.OrderInfo(
                 subaccount_id=subaccount_id,
                 fee_recipient=fee_recipient,
                 price=str(price),
@@ -222,20 +223,20 @@ class Composer:
         quantity = binary_options_quantity_to_backend(quantity, denom)
 
         if kwargs.get("is_buy") and not kwargs.get("is_po"):
-            order_type = injective_exchange_pb.OrderType.BUY
+            order_type = injective_dot_exchange_dot_v1beta1_dot_exchange__pb2.OrderType.BUY
 
         elif not kwargs.get("is_buy") and not kwargs.get("is_po"):
-            order_type = injective_exchange_pb.OrderType.SELL
+            order_type = injective_dot_exchange_dot_v1beta1_dot_exchange__pb2.OrderType.SELL
 
         elif kwargs.get("is_buy") and kwargs.get("is_po"):
-            order_type = injective_exchange_pb.OrderType.BUY_PO
+            order_type = injective_dot_exchange_dot_v1beta1_dot_exchange__pb2.OrderType.BUY_PO
 
         elif not kwargs.get("is_buy") and kwargs.get("is_po"):
-            order_type = injective_exchange_pb.OrderType.SELL_PO
+            order_type = injective_dot_exchange_dot_v1beta1_dot_exchange__pb2.OrderType.SELL_PO
 
-        return injective_exchange_pb.DerivativeOrder(
+        return injective_dot_exchange_dot_v1beta1_dot_exchange__pb2.DerivativeOrder(
             market_id=market_id,
-            order_info=injective_exchange_pb.OrderInfo(
+            order_info=injective_dot_exchange_dot_v1beta1_dot_exchange__pb2.OrderInfo(
                 subaccount_id=subaccount_id,
                 fee_recipient=fee_recipient,
                 price=str(price),
