@@ -96,11 +96,11 @@ class Network:
     @classmethod
     def testnet(cls):
         return cls(
-            lcd_endpoint='https://testnet.lcd.injective.network',
-            tm_websocket_endpoint='wss://testnet.tm.injective.network/websocket',
-            grpc_endpoint='testnet.grpc.injective.network',
-            grpc_exchange_endpoint='testnet.exchange.grpc.injective.network',
-            grpc_explorer_endpoint='testnet.explorer.grpc.injective.network',
+            lcd_endpoint='https://k8s.testnet.lcd.injective.network',
+            tm_websocket_endpoint='wss://k8s.testnet.tm.injective.network/websocket',
+            grpc_endpoint='k8s.testnet.chain.grpc.injective.network:443',
+            grpc_exchange_endpoint='k8s.testnet.exchange.grpc.injective.network:443',
+            grpc_explorer_endpoint='k8s.testnet.explorer.grpc.injective.network:443',
             chain_id='injective-888',
             fee_denom='inj',
             env='testnet'
@@ -109,12 +109,11 @@ class Network:
     @classmethod
     def mainnet(cls, node='lb'):
         nodes = [
-            'k8s',
-            'lb',
-            'sentry0',  # us, prod
-            'sentry1',  # us, prod
-            'sentry2',  # us, staging
-            'sentry3',  # tokyo, prod
+            'k8s', # us, prod
+            'lb', # us, asia, prod
+            'sentry0',  # ca, prod
+            'sentry1',  # ca, prod
+            'sentry3',  # us, prod
         ]
         if node not in nodes:
             raise ValueError('Must be one of {}'.format(nodes))
